Crate super_visor

Crate super_visor 

Structs

ShutdownSignal
An awaitable construct for signalling shutdown to supervised processes to complete work and exit on the next available await point Lazily instantiates the future when the future is first polled to allow cloning the underlying token and propagating shutdown signals from a single source in a one-to-many relationship
Supervisor
Manages the lifecycle of multiple async workers with coordinated, ordered shutdown.
SupervisorBuilder
Builder for constructing a Supervisor.

Enums

SupervisorError
Error type returned from task operations

Traits

ManagedProc
A trait for types that can be managed as long-running async tasks.

Functions

run
Boxes a future without spawning a separate managed task
spawn
Spawns a future ito its own Tokio task.

Type Aliases

BoxError
A boxed error type for errors raised in calling code
ManagedFuture
The return type for managed processes
ProcResult
Result type for supervised process operations